//
//  BCAppDelegate.m
//  BarCampSkeleton
//
//  Author: George Brocklehurst, http://georgebrock.com
//  Released under Creative Commons BY 2.0
//  http://creativecommons.org/licenses/by/2.0/uk/
//

#import "BCAppDelegate.h"
#import "BCJavascriptInterface.h"


@implementation BCAppDelegate

// This method will be called when the application is loaded
// This is because this object is the App's delegate
- (void)applicationDidFinishLaunching:(NSNotification *)aNotification
{
	// Create the Javascript interface
	// We'll release it in the dealloc method
	javascriptInterface = [[BCJavascriptInterface alloc] init];
	
	// Give the web view a transparent background
	[webView setDrawsBackground:FALSE];
	
	// Find the path to "index.html" in the resources
	NSString *htmlPath = [[NSBundle mainBundle] 
		pathForResource:@"index" ofType:@"html"];
		
	// Convert the path to a URL
	NSURL *htmlURL = [NSURL fileURLWithPath:htmlPath];
	
	// Load the URL
	[[webView mainFrame] 
		loadRequest:[NSURLRequest requestWithURL:htmlURL]];
}

// Standard method called when the object is free'd
- (void)dealloc
{
	// Release the javascript interface object
	[javascriptInterface release], javascriptInterface = nil;
	
	// Call the super class's dealloc method
	// You must include this call in dealloc
	[super dealloc];
}

// WebView delegate method
// Called by the web view when a page loads and the DOM is ready
- (void)webView:(WebView *)sender 
	windowScriptObjectAvailable:(WebScriptObject *)windowScriptObject
{
	// Pass the javascriptInterface object to the JS DOM
	// Accessible in JS by using window.app
	[windowScriptObject setValue:javascriptInterface forKey:@"app"];
}

// Wrapper method to make it easy to call Javascript functions
// From other classes use [[NSApp delegate] callJavascript...]
- (id)callJavascriptFunction:(NSString*)funcName 
		withArguments:(NSArray*)args
{
	// Get the window script object from the WebView and call the
	// relevant Javascript method
	return [[webView windowScriptObject] 
		callWebScriptMethod:funcName withArguments:args];
}

@end
